HasGather

Trait HasGather 

pub trait HasGather { }
This is a marker trait to represent the constraints on OpImageGather too complex to be represented by const generics. Specifically:

“Its OpTypeImage must have a Dim of 2D, Cube, or Rect. The MS operand of the underlying OpTypeImage must be 0.”

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasGather for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasGather for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasGather for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>