HasQueryLevels

Trait HasQueryLevels 

pub trait HasQueryLevels { }
This is a marker trait to represent the constraints on OpImageQueryLevels and OpImageQueryLod too complex to be represented by const generics. Specifically:

“Its Dim operand must be one of 1D, 2D, 3D, or Cube.”

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const MULTISAMPLED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQueryLevels for Image<SampledType, { _ }, DEPTH, ARRAYED, MULTISAMPLED, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const MULTISAMPLED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQueryLevels for Image<SampledType, { _ }, DEPTH, ARRAYED, MULTISAMPLED, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const MULTISAMPLED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQueryLevels for Image<SampledType, { _ }, DEPTH, ARRAYED, MULTISAMPLED, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const MULTISAMPLED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQueryLevels for Image<SampledType, { _ }, DEPTH, ARRAYED, MULTISAMPLED, SAMPLED, FORMAT, COMPONENTS>