HasQuerySizeLod

Trait HasQuerySizeLod 

pub trait HasQuerySizeLod { }
This is a marker trait to represent the constraints on OpImageQuerySizeLod too complex to be represented by const generics. Specifically:

“Its Dim operand must be one of 1D, 2D, 3D, or Cube, and its MS must be 0.”

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQuerySizeLod for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQuerySizeLod for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQuerySizeLod for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>

Source

impl<SampledType: SampleType<FORMAT, COMPONENTS>, const DEPTH: u32, const FORMAT: u32, const ARRAYED: u32, const SAMPLED: u32, const COMPONENTS: u32> HasQuerySizeLod for Image<SampledType, { _ }, DEPTH, ARRAYED, { _ }, SAMPLED, FORMAT, COMPONENTS>