#[repr(C)]pub struct TraceRaysIndirectCommand2KHR {Show 14 fields
pub raygen_shader_record_address: DeviceAddress,
pub raygen_shader_record_size: DeviceSize,
pub miss_shader_binding_table_address: DeviceAddress,
pub miss_shader_binding_table_size: DeviceSize,
pub miss_shader_binding_table_stride: DeviceSize,
pub hit_shader_binding_table_address: DeviceAddress,
pub hit_shader_binding_table_size: DeviceSize,
pub hit_shader_binding_table_stride: DeviceSize,
pub callable_shader_binding_table_address: DeviceAddress,
pub callable_shader_binding_table_size: DeviceSize,
pub callable_shader_binding_table_stride: DeviceSize,
pub width: u32,
pub height: u32,
pub depth: u32,
}Expand description
Structure specifying the parameters of an indirect trace ray command with indirect shader binding tables
Fields
raygen_shader_record_address: DeviceAddressraygenShaderRecordAddress is a VkDeviceAddress of the ray generation shader binding table record used by this command.
raygen_shader_record_size: DeviceSizeraygenShaderRecordSize is a VkDeviceSize number of bytes corresponding to the ray generation shader binding table record at base address raygenShaderRecordAddress.
miss_shader_binding_table_address: DeviceAddressmissShaderBindingTableAddress is a VkDeviceAddress of the first record in the miss shader binding table used by this command.
miss_shader_binding_table_size: DeviceSizemissShaderBindingTableSize is a VkDeviceSize number of bytes corresponding to the total size of the miss shader binding table at missShaderBindingTableAddress that may be accessed by this command.
miss_shader_binding_table_stride: DeviceSizemissShaderBindingTableStride is a VkDeviceSize number of bytes between records of the miss shader binding table.
hit_shader_binding_table_address: DeviceAddresshitShaderBindingTableAddress is a VkDeviceAddress of the first record in the hit shader binding table used by this command.
hit_shader_binding_table_size: DeviceSizehitShaderBindingTableSize is a VkDeviceSize number of bytes corresponding to the total size of the hit shader binding table at hitShaderBindingTableAddress that may be accessed by this command.
hit_shader_binding_table_stride: DeviceSizehitShaderBindingTableStride is a VkDeviceSize number of bytes between records of the hit shader binding table.
callable_shader_binding_table_address: DeviceAddresscallableShaderBindingTableAddress is a VkDeviceAddress of the first record in the callable shader binding table used by this command.
callable_shader_binding_table_size: DeviceSizecallableShaderBindingTableSize is a VkDeviceSize number of bytes corresponding to the total size of the callable shader binding table at callableShaderBindingTableAddress that may be accessed by this command.
callable_shader_binding_table_stride: DeviceSizecallableShaderBindingTableStride is a VkDeviceSize number of bytes between records of the callable shader binding table.
width: u32width is the width of the ray trace query dimensions.
height: u32height is height of the ray trace query dimensions.
depth: u32depth is depth of the ray trace query dimensions.