pub struct Semantics(/* private fields */);Expand description
Memory semantics to determine how some operations should function - used when calling such configurable operations.
Implementations
Sourceimpl Semantics
impl Semantics
Sourcepub const ACQUIRE: Self
pub const ACQUIRE: Self
On an atomic instruction, orders memory operations provided in program order after this atomic instruction against this atomic instruction. On a barrier, orders memory operations provided in program order after this barrier against atomic instructions before this barrier.
Sourcepub const RELEASE: Self
pub const RELEASE: Self
On an atomic instruction, orders memory operations provided in program order before this atomic instruction against this atomic instruction. On a barrier, orders memory operations provided in program order before this barrier against atomic instructions after this barrier.
Sourcepub const ACQUIRE_RELEASE: Self
pub const ACQUIRE_RELEASE: Self
Has the properties of both Self::ACQUIRE and Self::RELEASE semantics. It
is used for read-modify-write operations.
Sourcepub const SEQUENTIALLY_CONST: Self
pub const SEQUENTIALLY_CONST: Self
All observers see this memory access in the same order with respect to
other sequentially-consistent memory accesses from this invocation.
If the declared memory model is vulkan, SEQUENTIALLY_CONST must
not be used.
Sourcepub const UNIFORM_MEMORY: Self
pub const UNIFORM_MEMORY: Self
Apply the memory-ordering constraints to
[crate::storage_class::StorageBuffer],
[crate::storage_class::PhysicalStorageBuffer], or
[crate::storage_class::Uniform] Storage Class memory.
Sourcepub const SUBGROUP_MEMORY: Self
pub const SUBGROUP_MEMORY: Self
Apply the memory-ordering constraints to subgroup memory.
Sourcepub const WORKGROUP_MEMORY: Self
pub const WORKGROUP_MEMORY: Self
Apply the memory-ordering constraints to
[crate::storage_class::Workgroup] Storage Class memory.
Sourcepub const CROSS_WORKGROUP_MEMORY: Self
pub const CROSS_WORKGROUP_MEMORY: Self
Apply the memory-ordering constraints to
[crate::storage_class::CrossWorkgroup] Storage Class memory.
Sourcepub const ATOMIC_COUNTER_MEMORY: Self
pub const ATOMIC_COUNTER_MEMORY: Self
Apply the memory-ordering constraints to
[crate::storage_class::AtomicCounter] Storage Class memory.
Sourcepub const IMAGE_MEMORY: Self
pub const IMAGE_MEMORY: Self
Apply the memory-ordering constraints to image contents (types declared
by OpTypeImage), or to accesses done through pointers to the
[crate::storage_class::Image] Storage Class.
Sourcepub const OUTPUT_MEMORY: Self
pub const OUTPUT_MEMORY: Self
Apply the memory-ordering constraints to the
[crate::storage_class::Output] Storage Class memory.
Sourcepub const MAKE_AVAILABLE: Self
pub const MAKE_AVAILABLE: Self
Perform an availability operation on all references in the selected storage classes.
Sourcepub const MAKE_VISIBLE: Self
pub const MAKE_VISIBLE: Self
Perform a visibility operation on all references in the selected storage classes.
Sourceimpl Semantics
impl Semantics
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Semantics
impl Semantics
Sourcepub const fn iter(&self) -> Iter<Semantics>
pub const fn iter(&self) -> Iter<Semantics>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Semantics>
pub const fn iter_names(&self) -> IterNames<Semantics>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.