pub struct RayFlags(/* private fields */);Expand description
Flags controlling the properties of an OpTraceRayKHR instruction.
Despite being a mask and allowing multiple bits to be combined, it is
invalid for more than one of these four bits to be set: OPAQUE,
NO_OPAQUE, CULL_OPAQUE, CULL_NO_OPAQUE, only one of
CULL_BACK_FACING_TRIANGLES and CULL_FRONT_FACING_TRIANGLES may
be set.
Implementations
Sourceimpl RayFlags
impl RayFlags
Sourcepub const TERMINATE_ON_FIRST_HIT: Self
pub const TERMINATE_ON_FIRST_HIT: Self
Accept the first hit discovered.
Sourcepub const SKIP_CLOSEST_HIT_SHADER: Self
pub const SKIP_CLOSEST_HIT_SHADER: Self
Do not execute a closest hit shader.
Sourcepub const CULL_BACK_FACING_TRIANGLES: Self
pub const CULL_BACK_FACING_TRIANGLES: Self
Do not intersect with the back face of triangles.
Sourcepub const CULL_FRONT_FACING_TRIANGLES: Self
pub const CULL_FRONT_FACING_TRIANGLES: Self
Do not intersect with the front face of triangles.
Sourcepub const CULL_OPAQUE: Self
pub const CULL_OPAQUE: Self
Do not intersect with opaque geometry.
Sourcepub const CULL_NO_OPAQUE: Self
pub const CULL_NO_OPAQUE: Self
Do not intersect with non-opaque geometry.
Sourcepub const SKIP_TRIANGLES: Self
pub const SKIP_TRIANGLES: Self
Do not intersect with any triangle geometries.
Sourcepub const SKIP_AABBS: Self
pub const SKIP_AABBS: Self
Do not intersect with any AABB (Axis Aligned Bounding Box) geometries.
Sourceimpl RayFlags
impl RayFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RayFlags
impl RayFlags
Sourcepub const fn iter(&self) -> Iter<RayFlags>
pub const fn iter(&self) -> Iter<RayFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RayFlags>
pub const fn iter_names(&self) -> IterNames<RayFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.