VectorTruncateInto

Trait VectorTruncateInto 

pub trait VectorTruncateInto<T> {
    // Required method
    fn truncate_into(self) -> T;
}
Trait that implements slicing of a vector into a scalar or vector of lower dimensions, by ignoring the highter dimensions

Required Methods

fn truncate_into(self) -> T

Slices the vector into a lower dimensional type by ignoring the higher components

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl VectorTruncateInto<DVec2> for DVec2

Source

impl VectorTruncateInto<DVec2> for DVec3

Source

impl VectorTruncateInto<DVec2> for DVec4

Source

impl VectorTruncateInto<DVec3> for DVec3

Source

impl VectorTruncateInto<DVec3> for DVec4

Source

impl VectorTruncateInto<DVec4> for DVec4

Source

impl VectorTruncateInto<IVec2> for IVec2

Source

impl VectorTruncateInto<IVec2> for IVec3

Source

impl VectorTruncateInto<IVec2> for IVec4

Source

impl VectorTruncateInto<IVec3> for IVec3

Source

impl VectorTruncateInto<IVec3> for IVec4

Source

impl VectorTruncateInto<IVec4> for IVec4

Source

impl VectorTruncateInto<UVec2> for UVec2

Source

impl VectorTruncateInto<UVec2> for UVec3

Source

impl VectorTruncateInto<UVec2> for UVec4

Source

impl VectorTruncateInto<UVec3> for UVec3

Source

impl VectorTruncateInto<UVec3> for UVec4

Source

impl VectorTruncateInto<UVec4> for UVec4

Source

impl VectorTruncateInto<Vec2> for Vec2

Source

impl VectorTruncateInto<Vec2> for Vec3

Source

impl VectorTruncateInto<Vec2> for Vec4

Source

impl VectorTruncateInto<Vec3> for Vec3

Source

impl VectorTruncateInto<Vec3> for Vec4

Source

impl VectorTruncateInto<Vec4> for Vec4

Source

impl VectorTruncateInto<f32> for Vec2

Source

impl VectorTruncateInto<f32> for Vec3

Source

impl VectorTruncateInto<f32> for Vec4

Source

impl VectorTruncateInto<f32> for f32

Source

impl VectorTruncateInto<f64> for DVec2

Source

impl VectorTruncateInto<f64> for DVec3

Source

impl VectorTruncateInto<f64> for DVec4

Source

impl VectorTruncateInto<f64> for f64

Source

impl VectorTruncateInto<i32> for IVec2

Source

impl VectorTruncateInto<i32> for IVec3

Source

impl VectorTruncateInto<i32> for IVec4

Source

impl VectorTruncateInto<i32> for i32

Source

impl VectorTruncateInto<u32> for UVec2

Source

impl VectorTruncateInto<u32> for UVec3

Source

impl VectorTruncateInto<u32> for UVec4

Source

impl VectorTruncateInto<u32> for u32

Implementors